==> 2.0.3.tar.gz: lib/services/apk_backup.dart <==
import 'package:flutter/services.dart';

import 'package:apk_admin/utils/platform_error_handler.dart';

/// This class handles all backups logic that is implemented by the plugin.
class ApkBackup {
  static const _channel = MethodChannel('com.heda.apk_admin.apk_backup');

  /// This method creates "backups" folder if not exists under your app files folder
  /// and saves a backup apk of the specified app.
  /// ```
  /// Note that all backups gets stored in your app file directory
  /// under a sub directory called ""backups"
  /// for example if your app package name is com.example.name then backups will be
  /// stored under /storage/emulated/0/Android/data/com.example.name/files/backups .
  Future<String> makeBackup(String packageName) async {
    assert(packageName.isNotEmpty, "packageName can not be empty!");
    try {
      String backupResult = await _channel.invokeMethod(
        "makeBackup",
        {"packageName": packageName},
      );
      return backupResult;
    } on PlatformException catch (e) {
      throwError(e, "making a backup for $packageName");
      return "UnexpectedError";
    }
  }

  /// This method prompts a dialog to the user that asks for his confirmation
  /// to install the backup apk from the specified path.
  Future<String> restoreAppFromBackup(String apkPath) async {
    assert(apkPath.isNotEmpty, "apkPath can not be empty!");
    try {
      bool calledSuccessfully = await _channel.invokeMethod(
        "restoreAppFromBackup",
        {"apkPath": apkPath},
      );
      return calledSuccessfully ? "CalledSuccessfully" : "FileNotFound";
    } on PlatformException catch (e) {
      throwError(e, "installing an app from backup");
      return "UnexpectedError";
    }
  }
}

==> 2.2.4.tar.gz: lib/services/apk_backup.dart <==
import 'package:flutter/services.dart';

import 'package:apk_admin/utils/platform_error_handler.dart';

/// This class handles all backups logic that is implemented by the plugin.
class ApkBackup {
  static const _channel = MethodChannel('com.heda.apk_admin.apk_backup');

  /// This method creates "backups" folder if not exists under your app files folder
  /// and saves a backup apk of the specified app.
  /// ```
  /// Note that all backups gets stored in your app file directory
  /// under a sub directory called ""backups"
  /// for example if your app package name is com.example.name then backups will be
  /// stored under /storage/emulated/0/Android/data/com.example.name/files/backups .
  Future<String?> makeBackup(String packageName) async {
    assert(packageName.isNotEmpty, "packageName can not be empty!");
    try {
      String? backupResult = await _channel.invokeMethod(
        "makeBackup",
        {"packageName": packageName},
      );
      return backupResult;
    } on PlatformException catch (e) {
      throwError(e, "making a backup for $packageName");
      return "UnexpectedError";
    }
  }

  /// This method prompts a dialog to the user that asks for his confirmation
  /// to install the backup apk from the specified path.
  Future<String> restoreAppFromBackup(String apkPath) async {
    assert(apkPath.isNotEmpty, "apkPath can not be empty!");
    try {
      bool calledSuccessfully = await (_channel.invokeMethod(
        "restoreAppFromBackup",
        {"apkPath": apkPath},
      ));
      return calledSuccessfully ? "CalledSuccessfully" : "FileNotFound";
    } on PlatformException catch (e) {
      throwError(e, "installing an app from backup");
      return "UnexpectedError";
    }
  }
}
